@@ -1,13 +1,15 @@
-// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
 //
-// SPDX-License-Identifier: LGPL-3.0-or-later
-
-#ifndef TITLELABEL_H
-#define TITLELABEL_H
+//SPDX-License-Identifier: GPL-3.0-or-later
+#pragma once
 
+#include "interface/namespace.h"
 #include <DLabel>
 
-class TitleLabel : public DTK_NAMESPACE::Widget::DLabel
+namespace DCC_NAMESPACE
+{
+
+class TitleLabel : public Dtk::Widget::DLabel
 {
     Q_OBJECT
 public:
@@ -18,4 +20,4 @@ protected:
     bool event(QEvent *e) override;
 };
 
-#endif // TITLELABEL_H
+} // namespace DCC_NAMESPACE
